Add QuicStreamsBlockedFrame and QuicMaxStreamsFrame classes
There are two main parts to this work
1) connecting up the new frames, replacing the old ones, to move data around the
system. This also entails a lot of editorial changes (just changing names, comments,
and so on, without notable logic chanages -- eg, "OnMaxStreamIdFrame" becomes
"OnMaxStreamsFrame".
2) the second, and more complex, task is revising the stream id manager to work entirely
with stream counts rather than stream-ids. For example, the logic to check whether a
new stream can be created checks if the current-stream-count is less than the limit
or not, rather than if the next stream id to hand out is above the limit or not.
For all intents and purposes, this completely rewrote the stream ID manager.
Another big change resulting from keeping track solely of stream counts is that the
stream ID manager doesn't care whether it is doing unidirectional or bidirectional
streams, nor does it care whether stream ids are client- or server- initiated.
gfe-relnote: N/A, all changes are for V99/IETF QUIC code only.
LOG_STORAGE_INCREASE(GB/week): 0
TMPLOG_STORAGE_INCREASE(GB): 0
This change neither adds nor deletes data stored. It adds two new codepoints to the QUIC FrameType enum. These new enums reflect two new frames defined in IETF QUIC, which replace two now-deprecated frames (and their associated type codepoints). This is a name change/type codepoint extension; data is neither added nor deleted.
PiperOrigin-RevId: 244661277
Change-Id: I07cdb79db6bd15e1d5ece97b3aa2d67e94ccf00b
diff --git a/quic/core/quic_control_frame_manager.h b/quic/core/quic_control_frame_manager.h
index a5213c4..a4c2678 100644
--- a/quic/core/quic_control_frame_manager.h
+++ b/quic/core/quic_control_frame_manager.h
@@ -54,13 +54,13 @@
// immediately.
void WriteOrBufferBlocked(QuicStreamId id);
// Tries to send a STREAM_ID_BLOCKED Frame. Buffers the frame if it cannot be
// sent immediately.
- void WriteOrBufferStreamIdBlocked(QuicStreamId id);
+ void WriteOrBufferStreamsBlocked(QuicStreamCount count, bool unidirectional);
- // Tries to send a MAX_STREAM_ID Frame. Buffers the frame if it cannot be sent
+ // Tries to send a MAX_STREAMS Frame. Buffers the frame if it cannot be sent
// immediately.
- void WriteOrBufferMaxStreamId(QuicStreamId id);
+ void WriteOrBufferMaxStreams(QuicStreamCount count, bool unidirectional);
// Tries to send an IETF-QUIC STOP_SENDING frame. The frame is buffered if it
// can not be sent immediately.
@@ -54,13 +54,13 @@
// immediately.
void WriteOrBufferBlocked(QuicStreamId id);
- // Tries to send a STREAM_ID_BLOCKED Frame. Buffers the frame if it cannot be
+ // Tries to send a STREAMS_BLOCKED Frame. Buffers the frame if it cannot be
// sent immediately.